@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: warp-tls
 version: 3.2.1
-id: warp-tls-3.2.1-997d87dd11b6a7d0ddf72c51738cbc7b
-key: warpt_1lHdIJT6rgtLWAtBjzZmp5
+id: warp-tls-3.2.1-13a4c943553469ba64944024cd545da4
+key: warpt_589DEaQ3cdx7CgwFCjKZOb
 license: MIT
 maintainer: michael@snoyman.com
 stability: Stable
@@ -23,16 +23,16 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/warp-tls-3.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/warp-tls-3.2.1
-hs-libraries: HSwarp-tls-3.2.1-1lHdIJT6rgtLWAtBjzZmp5
+hs-libraries: HSwarp-tls-3.2.1-589DEaQ3cdx7CgwFCjKZOb
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
+    streaming-commons-0.1.15.4-088f3eb5ae9c0f8f3bf543f124c940b6
     tls-1.3.5-cc53341e73a1ad5e4154c36129b6c569
-    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
-    warp-3.2.6-828a707afef115eb99ae18cc2d425cf2
+    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
+    warp-3.2.6-88951d0d70fd1890006e06da62bd7b17
 haddock-interfaces: /usr/share/doc/haskell-warp-tls/html/warp-tls.haddock
 haddock-html: /usr/share/doc/haskell-warp-tls/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
